# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: credential_server.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'credential_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63redential_server.proto\"{\n\x15SetCredentialsRequest\x12\x13\n\x06\x65ntity\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07service\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x0b\x63redentials\x18\x03 \x03(\x0b\x32\x0b.CredentialB\t\n\x07_entityB\n\n\x08_service\"V\n\x12\x43redentialsRequest\x12\x13\n\x06\x65ntity\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07service\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_entityB\n\n\x08_service\"D\n\nCredential\x12\x10\n\x03key\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_keyB\x08\n\x06_value\"/\n\x0b\x43redentials\x12 \n\x0b\x63redentials\x18\x01 \x03(\x0b\x32\x0b.Credential\"8\n\x12\x43redentialResponse\x12\x15\n\x08response\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_response2\x8a\x01\n\x10\x43redentialServer\x12\x35\n\x0eGetCredentials\x12\x13.CredentialsRequest\x1a\x0c.Credentials\"\x00\x12?\n\x0eSetCredentials\x12\x16.SetCredentialsRequest\x1a\x13.CredentialResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credential_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SETCREDENTIALSREQUEST']._serialized_start=27
  _globals['_SETCREDENTIALSREQUEST']._serialized_end=150
  _globals['_CREDENTIALSREQUEST']._serialized_start=152
  _globals['_CREDENTIALSREQUEST']._serialized_end=238
  _globals['_CREDENTIAL']._serialized_start=240
  _globals['_CREDENTIAL']._serialized_end=308
  _globals['_CREDENTIALS']._serialized_start=310
  _globals['_CREDENTIALS']._serialized_end=357
  _globals['_CREDENTIALRESPONSE']._serialized_start=359
  _globals['_CREDENTIALRESPONSE']._serialized_end=415
  _globals['_CREDENTIALSERVER']._serialized_start=418
  _globals['_CREDENTIALSERVER']._serialized_end=556
# @@protoc_insertion_point(module_scope)
