# Generated protobuf stubs for observability platform
# Run `make proto` or `./scripts/generate_proto.sh` to regenerate

from . import (
    credential_server_pb2,
    credential_server_pb2_grpc,
    observability_pb2,
    observability_pb2_grpc,
    policy_engine_pb2,
    policy_engine_pb2_grpc,
    reference_monitor_pb2,
    reference_monitor_pb2_grpc,
)

__all__ = [
    "credential_server_pb2",
    "credential_server_pb2_grpc",
    "observability_pb2",
    "observability_pb2_grpc",
    "policy_engine_pb2",
    "policy_engine_pb2_grpc",
    "reference_monitor_pb2",
    "reference_monitor_pb2_grpc",
]
