# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: policy_engine.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'policy_engine.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13policy_engine.proto\x12\rpolicy_engine\"\x87\x01\n\x14\x41uthorizationRequest\x12\x18\n\x10\x63urrent_node_ids\x18\x01 \x03(\t\x12&\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x15.policy_engine.Action\x12\x13\n\x06\x65ntity\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05roles\x18\x04 \x03(\tB\t\n\x07_entity\"\xbf\x01\n\x06\x41\x63tion\x12\x38\n\x0chttp_request\x18\x01 \x01(\x0b\x32 .policy_engine.HttpRequestActionH\x00\x12\x32\n\ttool_call\x18\x02 \x01(\x0b\x32\x1d.policy_engine.ToolCallActionH\x00\x12\x38\n\x0csend_message\x18\x03 \x01(\x0b\x32 .policy_engine.SendMessageActionH\x00\x42\r\n\x0b\x61\x63tion_type\"V\n\x11HttpRequestAction\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12&\n\x07headers\x18\x03 \x03(\x0b\x32\x15.policy_engine.Header\"$\n\x06Header\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"/\n\x0eToolCallAction\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\t\"\x94\x01\n\x11SendMessageAction\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\r\n\x05\x61gent\x18\x02 \x01(\t\x12\x12\n\nagent_role\x18\x03 \x01(\t\x12+\n\ntool_calls\x18\x04 \x03(\x0b\x32\x17.policy_engine.ToolCall\x12\x13\n\x06\x65ntity\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_entity\")\n\x08ToolCall\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\t\"E\n\x15\x41uthorizationResponse\x12,\n\x07results\x18\x01 \x03(\x0b\x32\x1b.policy_engine.ActionResult\"\xa0\x01\n\x0c\x41\x63tionResult\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\nauthorized\x18\x02 \x01(\x08\x12.\n\x05trace\x18\x03 \x01(\x0b\x32\x1a.policy_engine.DenialTraceH\x00\x88\x01\x01\x12\x15\n\rtransform_ids\x18\x04 \x03(\t\x12\x1c\n\x14\x64\x65ny_if_unauthorized\x18\x05 \x01(\x08\x42\x08\n\x06_trace\"p\n\x0b\x44\x65nialTrace\x12\x1a\n\x12\x61\x63tion_description\x18\x01 \x01(\t\x12,\n\x07reasons\x18\x02 \x03(\x0b\x32\x1b.policy_engine.DenialReason\x12\x17\n\x0fsuggested_fixes\x18\x03 \x03(\t\"\x87\x01\n\x0c\x44\x65nialReason\x12\x34\n\x0breason_type\x18\x01 \x01(\x0e\x32\x1f.policy_engine.DenialReasonType\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\x12\x1c\n\x0fsource_location\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_source_location\"\x13\n\x11SyncStatusRequest\"i\n\x12SyncStatusResponse\x12\x18\n\x10\x63urrent_sequence\x18\x01 \x01(\x03\x12\x12\n\nnode_count\x18\x02 \x01(\x03\x12\x12\n\nedge_count\x18\x03 \x01(\x03\x12\x11\n\tconnected\x18\x04 \x01(\x08\"\x0f\n\rHealthRequest\"2\n\x0eHealthResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t*n\n\x10\x44\x65nialReasonType\x12\x1d\n\x19\x44\x45NIAL_REASON_UNSPECIFIED\x10\x00\x12\x15\n\x11NOT_AUTHENTICATED\x10\x01\x12\x0f\n\x0b\x42LACKLISTED\x10\x02\x12\x13\n\x0fNOT_WHITELISTED\x10\x03\x32\x8c\x02\n\x0cPolicyEngine\x12_\n\x12\x43heckAuthorization\x12#.policy_engine.AuthorizationRequest\x1a$.policy_engine.AuthorizationResponse\x12T\n\rGetSyncStatus\x12 .policy_engine.SyncStatusRequest\x1a!.policy_engine.SyncStatusResponse\x12\x45\n\x06Health\x12\x1c.policy_engine.HealthRequest\x1a\x1d.policy_engine.HealthResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy_engine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DENIALREASONTYPE']._serialized_start=1422
  _globals['_DENIALREASONTYPE']._serialized_end=1532
  _globals['_AUTHORIZATIONREQUEST']._serialized_start=39
  _globals['_AUTHORIZATIONREQUEST']._serialized_end=174
  _globals['_ACTION']._serialized_start=177
  _globals['_ACTION']._serialized_end=368
  _globals['_HTTPREQUESTACTION']._serialized_start=370
  _globals['_HTTPREQUESTACTION']._serialized_end=456
  _globals['_HEADER']._serialized_start=458
  _globals['_HEADER']._serialized_end=494
  _globals['_TOOLCALLACTION']._serialized_start=496
  _globals['_TOOLCALLACTION']._serialized_end=543
  _globals['_SENDMESSAGEACTION']._serialized_start=546
  _globals['_SENDMESSAGEACTION']._serialized_end=694
  _globals['_TOOLCALL']._serialized_start=696
  _globals['_TOOLCALL']._serialized_end=737
  _globals['_AUTHORIZATIONRESPONSE']._serialized_start=739
  _globals['_AUTHORIZATIONRESPONSE']._serialized_end=808
  _globals['_ACTIONRESULT']._serialized_start=811
  _globals['_ACTIONRESULT']._serialized_end=971
  _globals['_DENIALTRACE']._serialized_start=973
  _globals['_DENIALTRACE']._serialized_end=1085
  _globals['_DENIALREASON']._serialized_start=1088
  _globals['_DENIALREASON']._serialized_end=1223
  _globals['_SYNCSTATUSREQUEST']._serialized_start=1225
  _globals['_SYNCSTATUSREQUEST']._serialized_end=1244
  _globals['_SYNCSTATUSRESPONSE']._serialized_start=1246
  _globals['_SYNCSTATUSRESPONSE']._serialized_end=1351
  _globals['_HEALTHREQUEST']._serialized_start=1353
  _globals['_HEALTHREQUEST']._serialized_end=1368
  _globals['_HEALTHRESPONSE']._serialized_start=1370
  _globals['_HEALTHRESPONSE']._serialized_end=1420
  _globals['_POLICYENGINE']._serialized_start=1535
  _globals['_POLICYENGINE']._serialized_end=1803
# @@protoc_insertion_point(module_scope)
