# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: observability.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'observability.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13observability.proto\x12\robservability\"M\n\x0cGraphUpdates\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12+\n\x07updates\x18\x02 \x03(\x0b\x32\x1a.observability.GraphUpdate\".\n\x06\x45vents\x12$\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x14.observability.Event\"\xef\x01\n\x05\x45vent\x12\x11\n\x04text\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x61gent\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x04role\x18\x03 \x01(\x0e\x32\x13.observability.RoleH\x02\x88\x01\x01\x12\x0f\n\x02id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\"\n\x05tools\x18\x05 \x03(\x0b\x32\x13.observability.Tool\x12.\n\x0c\x64\x65rived_from\x18\x06 \x01(\x0b\x32\x13.observability.ToolH\x04\x88\x01\x01\x42\x07\n\x05_textB\x08\n\x06_agentB\x07\n\x05_roleB\x05\n\x03_idB\x0f\n\r_derived_from\"H\n\x04Tool\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\targuments\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_arguments\"\x12\n\x03IDs\x12\x0b\n\x03ids\x18\x01 \x03(\t\"2\n\x0c\x44\x65pendencies\x12\"\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x13.observability.Edge\"}\n\x04\x45\x64ge\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\x12\x1a\n\rmessage_index\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08proximal\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\x10\n\x0e_message_indexB\x0b\n\t_proximal\".\n\x08Response\x12\x15\n\x08response\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_response\"X\n\x0cSliceRequest\x12\x15\n\x08\x65vent_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmax_depth\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0b\n\t_event_idB\x0c\n\n_max_depth\"P\n\x05Graph\x12#\n\x05nodes\x18\x01 \x03(\x0b\x32\x14.observability.Event\x12\"\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x13.observability.Edge\"\x0e\n\x0cStateRequest\"h\n\nGraphState\x12$\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x14.observability.Event\x12\"\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x13.observability.Edge\x12\x10\n\x08sequence\x18\x03 \x01(\x03\"p\n\rStreamMessage\x12\x31\n\tsubscribe\x18\x01 \x01(\x0b\x32\x1c.observability.StreamRequestH\x00\x12!\n\x03\x61\x63k\x18\x02 \x01(\x0b\x32\x12.observability.AckH\x00\x42\t\n\x07message\"&\n\rStreamRequest\x12\x15\n\rfrom_sequence\x18\x01 \x01(\x03\"\x17\n\x03\x41\x63k\x12\x10\n\x08position\x18\x01 \x01(\x03\"\xcb\x05\n\x0bGraphUpdate\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.observability.UpdateType\x12(\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x14.observability.EventH\x00\x88\x01\x01\x12&\n\x04\x65\x64ge\x18\x03 \x01(\x0b\x32\x13.observability.EdgeH\x01\x88\x01\x01\x12\x14\n\x07node_id\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tsource_id\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1b\n\x0e\x64\x65stination_id\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x32\n\nfull_state\x18\x07 \x01(\x0b\x32\x19.observability.GraphStateH\x05\x88\x01\x01\x12\x16\n\ttimestamp\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x34\n\x0b\x63omputation\x18\t \x01(\x0b\x32\x1a.observability.ComputationH\x07\x88\x01\x01\x12=\n\x10\x63omputation_edge\x18\n \x01(\x0b\x32\x1e.observability.ComputationEdgeH\x08\x88\x01\x01\x12L\n\x18\x63omputation_message_edge\x18\x0b \x01(\x0b\x32%.observability.ComputationMessageEdgeH\t\x88\x01\x01\x12\x38\n\x0bstate_chunk\x18\x0c \x01(\x0b\x32\x1e.observability.GraphStateChunkH\n\x88\x01\x01\x42\x08\n\x06_eventB\x07\n\x05_edgeB\n\n\x08_node_idB\x0c\n\n_source_idB\x11\n\x0f_destination_idB\r\n\x0b_full_stateB\x0c\n\n_timestampB\x0e\n\x0c_computationB\x13\n\x11_computation_edgeB\x1b\n\x19_computation_message_edgeB\x0e\n\x0c_state_chunk\"[\n\x0fGraphStateChunk\x12$\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x14.observability.Event\x12\"\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x13.observability.Edge\"\xa0\x01\n\tSpanEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x02 \x01(\x04\x12<\n\nattributes\x18\x03 \x03(\x0b\x32(.observability.SpanEvent.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\rSpanAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x05 \x01(\x08H\x00\x12\x14\n\njson_value\x18\x06 \x01(\tH\x00\x42\x07\n\x05value\"\x89\x04\n\x0b\x43omputation\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\x1b\n\x0eparent_span_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x15\n\rstart_time_ns\x18\x05 \x01(\x04\x12\x13\n\x0b\x65nd_time_ns\x18\x06 \x01(\x04\x12\x13\n\x0b\x64uration_ns\x18\x07 \x01(\x04\x12\x32\n\x0bstatus_code\x18\x08 \x01(\x0e\x32\x1d.observability.SpanStatusCode\x12\x1b\n\x0estatus_message\x18\t \x01(\tH\x01\x88\x01\x01\x12\x17\n\x0f\x61ttributes_json\x18\n \x01(\t\x12\x13\n\x0b\x65vents_json\x18\x0b \x01(\t\x12\x19\n\x0cservice_name\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x1c\n\x0fservice_version\x18\r \x01(\tH\x03\x88\x01\x01\x12\x19\n\x11input_message_ids\x18\x0e \x03(\t\x12\x1e\n\x11output_message_id\x18\x0f \x01(\tH\x04\x88\x01\x01\x12\x17\n\x0flinked_span_ids\x18\x10 \x03(\tB\x11\n\x0f_parent_span_idB\x11\n\x0f_status_messageB\x0f\n\r_service_nameB\x12\n\x10_service_versionB\x14\n\x12_output_message_id\"@\n\x0c\x43omputations\x12\x30\n\x0c\x63omputations\x18\x01 \x03(\x0b\x32\x1a.observability.Computation\"@\n\x0f\x43omputationEdge\x12\x16\n\x0eparent_span_id\x18\x01 \x01(\t\x12\x15\n\rchild_span_id\x18\x02 \x01(\t\"\xa9\x01\n\x16\x43omputationMessageEdge\x12\x0f\n\x07span_id\x18\x01 \x01(\t\x12\x12\n\nmessage_id\x18\x02 \x01(\t\x12<\n\tedge_type\x18\x03 \x01(\x0e\x32).observability.ComputationMessageEdgeType\x12\x1a\n\rmessage_index\x18\x04 \x01(\x05H\x00\x88\x01\x01\x42\x10\n\x0e_message_index\"x\n\x0cTraceRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x1a\n\rstart_time_ns\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x18\n\x0b\x65nd_time_ns\x18\x03 \x01(\x04H\x01\x88\x01\x01\x42\x10\n\x0e_start_time_nsB\x0e\n\x0c_end_time_ns\"\x86\x01\n\x0bSpanRequest\x12\x0f\n\x07span_id\x18\x01 \x01(\t\x12\x1d\n\x10include_children\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10include_messages\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x13\n\x11_include_childrenB\x13\n\x11_include_messages\"\xdf\x01\n\nTraceGraph\x12\x30\n\x0c\x63omputations\x18\x01 \x03(\x0b\x32\x1a.observability.Computation\x12&\n\x08messages\x18\x02 \x03(\x0b\x32\x14.observability.Event\x12\x39\n\x11\x63omputation_edges\x18\x03 \x03(\x0b\x32\x1e.observability.ComputationEdge\x12<\n\rmessage_edges\x18\x04 \x03(\x0b\x32%.observability.ComputationMessageEdge*0\n\x04Role\x12\n\n\x06SYSTEM\x10\x00\x12\x08\n\x04USER\x10\x01\x12\x07\n\x03LLM\x10\x02\x12\t\n\x05\x41GENT\x10\x03*\xac\x02\n\nUpdateType\x12\r\n\tHEARTBEAT\x10\x00\x12\x10\n\x0cNODE_CREATED\x10\x01\x12\x10\n\x0cNODE_DELETED\x10\x02\x12\x10\n\x0c\x45\x44GE_CREATED\x10\x03\x12\x10\n\x0c\x45\x44GE_DELETED\x10\x04\x12\x0e\n\nFULL_STATE\x10\x05\x12\x17\n\x13\x43OMPUTATION_CREATED\x10\x06\x12\x17\n\x13\x43OMPUTATION_DELETED\x10\x07\x12\x1c\n\x18\x43OMPUTATION_EDGE_CREATED\x10\x08\x12$\n COMPUTATION_MESSAGE_LINK_CREATED\x10\t\x12\x14\n\x10\x46ULL_STATE_START\x10\n\x12\x14\n\x10\x46ULL_STATE_CHUNK\x10\x0b\x12\x15\n\x11\x46ULL_STATE_COMMIT\x10\x0c*C\n\x0eSpanStatusCode\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\r\n\tSTATUS_OK\x10\x01\x12\x10\n\x0cSTATUS_ERROR\x10\x02*8\n\x1a\x43omputationMessageEdgeType\x12\x0c\n\x08PRODUCES\x10\x00\x12\x0c\n\x08\x43ONSUMES\x10\x01\x32\xff\x03\n\rObservability\x12=\n\x0eRegisterEvents\x12\x15.observability.Events\x1a\x12.observability.IDs\"\x00\x12N\n\x14RegisterDependencies\x12\x1b.observability.Dependencies\x1a\x17.observability.Response\"\x00\x12\x44\n\rBackwardSlice\x12\x1b.observability.SliceRequest\x1a\x14.observability.Graph\"\x00\x12\x43\n\x0c\x46orwardSlice\x12\x1b.observability.SliceRequest\x1a\x14.observability.Graph\"\x00\x12I\n\x14RegisterComputations\x12\x1b.observability.Computations\x1a\x12.observability.IDs\"\x00\x12\x44\n\x08GetTrace\x12\x1b.observability.TraceRequest\x1a\x19.observability.TraceGraph\"\x00\x12\x43\n\x07GetSpan\x12\x1a.observability.SpanRequest\x1a\x1a.observability.Computation\"\x00\x32\xae\x01\n\x14ObservabilityUpdates\x12\x44\n\x08GetState\x12\x1b.observability.StateRequest\x1a\x19.observability.GraphState\"\x00\x12P\n\rStreamUpdates\x12\x1c.observability.StreamMessage\x1a\x1b.observability.GraphUpdates\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'observability_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SPANEVENT_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_SPANEVENT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_ROLE']._serialized_start=3641
  _globals['_ROLE']._serialized_end=3689
  _globals['_UPDATETYPE']._serialized_start=3692
  _globals['_UPDATETYPE']._serialized_end=3992
  _globals['_SPANSTATUSCODE']._serialized_start=3994
  _globals['_SPANSTATUSCODE']._serialized_end=4061
  _globals['_COMPUTATIONMESSAGEEDGETYPE']._serialized_start=4063
  _globals['_COMPUTATIONMESSAGEEDGETYPE']._serialized_end=4119
  _globals['_GRAPHUPDATES']._serialized_start=38
  _globals['_GRAPHUPDATES']._serialized_end=115
  _globals['_EVENTS']._serialized_start=117
  _globals['_EVENTS']._serialized_end=163
  _globals['_EVENT']._serialized_start=166
  _globals['_EVENT']._serialized_end=405
  _globals['_TOOL']._serialized_start=407
  _globals['_TOOL']._serialized_end=479
  _globals['_IDS']._serialized_start=481
  _globals['_IDS']._serialized_end=499
  _globals['_DEPENDENCIES']._serialized_start=501
  _globals['_DEPENDENCIES']._serialized_end=551
  _globals['_EDGE']._serialized_start=553
  _globals['_EDGE']._serialized_end=678
  _globals['_RESPONSE']._serialized_start=680
  _globals['_RESPONSE']._serialized_end=726
  _globals['_SLICEREQUEST']._serialized_start=728
  _globals['_SLICEREQUEST']._serialized_end=816
  _globals['_GRAPH']._serialized_start=818
  _globals['_GRAPH']._serialized_end=898
  _globals['_STATEREQUEST']._serialized_start=900
  _globals['_STATEREQUEST']._serialized_end=914
  _globals['_GRAPHSTATE']._serialized_start=916
  _globals['_GRAPHSTATE']._serialized_end=1020
  _globals['_STREAMMESSAGE']._serialized_start=1022
  _globals['_STREAMMESSAGE']._serialized_end=1134
  _globals['_STREAMREQUEST']._serialized_start=1136
  _globals['_STREAMREQUEST']._serialized_end=1174
  _globals['_ACK']._serialized_start=1176
  _globals['_ACK']._serialized_end=1199
  _globals['_GRAPHUPDATE']._serialized_start=1202
  _globals['_GRAPHUPDATE']._serialized_end=1917
  _globals['_GRAPHSTATECHUNK']._serialized_start=1919
  _globals['_GRAPHSTATECHUNK']._serialized_end=2010
  _globals['_SPANEVENT']._serialized_start=2013
  _globals['_SPANEVENT']._serialized_end=2173
  _globals['_SPANEVENT_ATTRIBUTESENTRY']._serialized_start=2124
  _globals['_SPANEVENT_ATTRIBUTESENTRY']._serialized_end=2173
  _globals['_SPANATTRIBUTE']._serialized_start=2176
  _globals['_SPANATTRIBUTE']._serialized_end=2326
  _globals['_COMPUTATION']._serialized_start=2329
  _globals['_COMPUTATION']._serialized_end=2850
  _globals['_COMPUTATIONS']._serialized_start=2852
  _globals['_COMPUTATIONS']._serialized_end=2916
  _globals['_COMPUTATIONEDGE']._serialized_start=2918
  _globals['_COMPUTATIONEDGE']._serialized_end=2982
  _globals['_COMPUTATIONMESSAGEEDGE']._serialized_start=2985
  _globals['_COMPUTATIONMESSAGEEDGE']._serialized_end=3154
  _globals['_TRACEREQUEST']._serialized_start=3156
  _globals['_TRACEREQUEST']._serialized_end=3276
  _globals['_SPANREQUEST']._serialized_start=3279
  _globals['_SPANREQUEST']._serialized_end=3413
  _globals['_TRACEGRAPH']._serialized_start=3416
  _globals['_TRACEGRAPH']._serialized_end=3639
  _globals['_OBSERVABILITY']._serialized_start=4122
  _globals['_OBSERVABILITY']._serialized_end=4633
  _globals['_OBSERVABILITYUPDATES']._serialized_start=4636
  _globals['_OBSERVABILITYUPDATES']._serialized_end=4810
# @@protoc_insertion_point(module_scope)
