# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: reference_monitor.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'reference_monitor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import policy_engine_pb2 as policy__engine__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17reference_monitor.proto\x1a\x13policy_engine.proto\"@\n\x06Header\x12\x10\n\x03key\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\x06\n\x04_keyB\x08\n\x06_value\"E\n\x07Message\x12\x18\n\x07headers\x18\x01 \x03(\x0b\x32\x07.Header\x12\x14\n\x07\x63ontent\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\n\n\x08_content\"s\n\x0b\x42\x61seRequest\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06method\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x07message\x18\x03 \x01(\x0b\x32\x08.MessageH\x02\x88\x01\x01\x42\x06\n\x04_urlB\t\n\x07_methodB\n\n\x08_message\"U\n\x0bHTTPRequest\x12\"\n\x07request\x18\x01 \x01(\x0b\x32\x0c.BaseRequestH\x00\x88\x01\x01\x12\x16\n\x0einput_node_ids\x18\x02 \x03(\tB\n\n\x08_request\"Z\n\x0cHTTPResponse\x12\x13\n\x06status\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x07message\x18\x02 \x01(\x0b\x32\x08.MessageH\x01\x88\x01\x01\x42\t\n\x07_statusB\n\n\x08_message\"H\n\x0fToolCallRequest\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\t\x12\x16\n\x0einput_node_ids\x18\x03 \x03(\t\"n\n\x10ToolCallResponse\x12\x12\n\nauthorized\x18\x01 \x01(\x08\x12\x35\n\x0c\x64\x65nial_trace\x18\x02 \x01(\x0b\x32\x1a.policy_engine.DenialTraceH\x00\x88\x01\x01\x42\x0f\n\r_denial_trace2o\n\x07RMProxy\x12,\n\tProxyHTTP\x12\x0c.HTTPRequest\x1a\r.HTTPResponse\"\x00\x30\x01\x12\x36\n\rCheckToolCall\x12\x10.ToolCallRequest\x1a\x11.ToolCallResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'reference_monitor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEADER']._serialized_start=48
  _globals['_HEADER']._serialized_end=112
  _globals['_MESSAGE']._serialized_start=114
  _globals['_MESSAGE']._serialized_end=183
  _globals['_BASEREQUEST']._serialized_start=185
  _globals['_BASEREQUEST']._serialized_end=300
  _globals['_HTTPREQUEST']._serialized_start=302
  _globals['_HTTPREQUEST']._serialized_end=387
  _globals['_HTTPRESPONSE']._serialized_start=389
  _globals['_HTTPRESPONSE']._serialized_end=479
  _globals['_TOOLCALLREQUEST']._serialized_start=481
  _globals['_TOOLCALLREQUEST']._serialized_end=553
  _globals['_TOOLCALLRESPONSE']._serialized_start=555
  _globals['_TOOLCALLRESPONSE']._serialized_end=665
  _globals['_RMPROXY']._serialized_start=667
  _globals['_RMPROXY']._serialized_end=778
# @@protoc_insertion_point(module_scope)
